part of 'login_bloc.dart';

abstract class LoginEvent extends Equatable {
  const LoginEvent();

  @override
  List<Object> get props => [];
}

class LoginEmailChange extends LoginEvent {
  final String email;
  const LoginEmailChange({required this.email});

  @override
  List<Object> get props => [email];
}

class LoginPasswordChange extends LoginEvent {
  final String password;
  const LoginPasswordChange({required this.password});

  @override
  List<Object> get props => [password];
}

class LoginPasswordChangeObscure extends LoginEvent {
  const LoginPasswordChangeObscure();
}

class LoginSubmit extends LoginEvent {
  const LoginSubmit();
}

class LoginFB extends LoginEvent {
  const LoginFB();
}

class LoginGoogle extends LoginEvent {
  const LoginGoogle();
}

class LoginApple extends LoginEvent {
  const LoginApple();
}

class LoginSkip extends LoginEvent {
  const LoginSkip();
}

class DataProtectionClicked extends LoginEvent {
  final bool marked;
  const DataProtectionClicked({required this.marked});
}

class EmailSubscriptionClicked extends LoginEvent {
  final bool marked;
  const EmailSubscriptionClicked({required this.marked});
}

class RegistrationSubmit extends LoginEvent {
  const RegistrationSubmit();
}

class RegistrationFB extends LoginEvent {
  const RegistrationFB();
}

class RegistrationGoogle extends LoginEvent {
  const RegistrationGoogle();
}

class RegistrationApple extends LoginEvent {
  const RegistrationApple();
}
